Getting started: Other algorithms
==================================

In AGOX many other algorithms than the very simple RSS algorithm shown so far 
can be used, see the :ref:`Search algorithms`-page for an overview. 